@@ -1,17 +1,12 @@
-# read version from installed package
-from importlib.metadata import version
-__version__ = version("python_automationshield")
-
 from .controller import ShieldController
 from .exception import AutomationShieldException
 from .shields import AeroShield, FloatShield, MagnetoShield, DummyShield
 
 
+# install arduino-cli if not present
 import platform
 
-from pathlib import Path
-
-from .arduino import download_cli, setup_cli, cli_dir, cli_path
+from .arduino import download_cli, setup_cli, cli_dir
 
 system = platform.system()
 
